@@ -98,10 +98,22 @@ class CoerciveIntEnum(IntEnum):
 
 
 class Align(CoerciveEnum):
+    "Defines how to render text in a cell"
+
     C = intern("CENTER")
+    "Center text horizontally"
+
+    X = intern("X_CENTER")
+    "Center text horizontally around current x position"
+
     L = intern("LEFT")
+    "Left-align text"
+
     R = intern("RIGHT")
+    "Right-align text"
+
     J = intern("JUSTIFY")
+    "Justify text"
 
     @classmethod
     def coerce(cls, value):
@@ -111,14 +123,36 @@ class Align(CoerciveEnum):
 
 
 class RenderStyle(CoerciveEnum):
+    "Defines how to render shapes"
+
     D = intern("DRAW")
+    """
+    Draw lines.
+    Line color can be controlled with `fpdf.fpdf.FPDF.set_draw_color()`.
+    Line thickness can be controlled with `fpdf.fpdf.FPDF.set_line_width()`.
+    """
+
     F = intern("FILL")
+    """
+    Fill areas.
+    Filling color can be controlled with `fpdf.fpdf.FPDF.set_fill_color()`.
+    """
+
     DF = intern("DRAW_FILL")
+    "Draw lines and fill areas"
 
     @property
     def operator(self):
         return {self.D: "S", self.F: "f", self.DF: "B"}[self]
 
+    @property
+    def is_draw(self):
+        return self in (self.D, self.DF)
+
+    @property
+    def is_fill(self):
+        return self in (self.F, self.DF)
+
     @classmethod
     def coerce(cls, value):
         if not value:
@@ -141,43 +175,106 @@ class TextMode(CoerciveIntEnum):
 
 
 class XPos(CoerciveEnum):
-    """
-    Positional values in horizontal direction for use after printing text.
-        LEFT    - left end of the cell
-        RIGHT   - right end of the cell (default)
-        START   - start of actual text
-        END     - end of actual text
-        WCONT   - for write() to continue next (slightly left of END)
-        CENTER  - center of actual text
-        LMARGIN - left page margin (start of printable area)
-        RMARGIN - right page margin (end of printable area)
-    """
+    "Positional values in horizontal direction for use after printing text."
 
     LEFT = intern("LEFT")  # self.x
+    "left end of the cell"
+
     RIGHT = intern("RIGHT")  # self.x + w
-    START = intern("START")  # left end of actual text
-    END = intern("END")  # right end of actual text
-    WCONT = intern("WCONT")  # continuation point for write()
-    CENTER = intern("CENTER")  # center of actual text
+    "right end of the cell (default)"
+
+    START = intern("START")
+    "left start of actual text"
+
+    END = intern("END")
+    "right end of actual text"
+
+    WCONT = intern("WCONT")
+    "for write() to continue next (slightly left of END)"
+
+    CENTER = intern("CENTER")
+    "center of actual text"
+
     LMARGIN = intern("LMARGIN")  # self.l_margin
+    "left page margin (start of printable area)"
+
     RMARGIN = intern("RMARGIN")  # self.w - self.r_margin
+    "right page margin (end of printable area)"
 
 
 class YPos(CoerciveEnum):
-    """
-    Positional values in vertical direction for use after printing text.
-        TOP     - top of the first line (default)
-        LAST    - top of the last line (same as TOP for single-line text)
-        NEXT    - top of next line (bottom of current text)
-        TMARGIN - top page margin (start of printable area)
-        BMARGIN - bottom page margin (end of printable area)
-    """
+    "Positional values in vertical direction for use after printing text"
 
     TOP = intern("TOP")  # self.y
-    LAST = intern("LAST")  # top of last line (TOP for single lines)
+    "top of the first line (default)"
+
+    LAST = intern("LAST")
+    "top of the last line (same as TOP for single-line text)"
+
     NEXT = intern("NEXT")  # LAST + h
+    "top of next line (bottom of current text)"
+
     TMARGIN = intern("TMARGIN")  # self.t_margin
+    "top page margin (start of printable area)"
+
     BMARGIN = intern("BMARGIN")  # self.h - self.b_margin
+    "bottom page margin (end of printable area)"
+
+
+class PageLayout(CoerciveEnum):
+    "Specify the page layout shall be used when the document is opened"
+
+    SINGLE_PAGE = Name("SinglePage")
+    "Display one page at a time"
+
+    ONE_COLUMN = Name("OneColumn")
+    "Display the pages in one column"
+
+    TWO_COLUMN_LEFT = Name("TwoColumnLeft")
+    "Display the pages in two columns, with odd-numbered pages on the left"
+
+    TWO_COLUMN_RIGHT = Name("TwoColumnRight")
+    "Display the pages in two columns, with odd-numbered pages on the right"
+
+    TWO_PAGE_LEFT = Name("TwoPageLeft")
+    "Display the pages two at a time, with odd-numbered pages on the left"
+
+    TWO_PAGE_RIGHT = Name("TwoPageRight")
+    "Display the pages two at a time, with odd-numbered pages on the right"
+
+
+class PageMode(CoerciveEnum):
+    "Specifying how to display the document on exiting full-screen mode"
+
+    USE_NONE = Name("UseNone")
+    "Neither document outline nor thumbnail images visible"
+
+    USE_OUTLINES = Name("UseOutlines")
+    "Document outline visible"
+
+    USE_THUMBS = Name("UseThumbs")
+    "Thumbnail images visible"
+
+    FULL_SCREEN = Name("FullScreen")
+    "Full-screen mode, with no menu bar, window controls, or any other window visible"
+
+    USE_OC = Name("UseOC")
+    "Optional content group panel visible"
+
+    USE_ATTACHMENTS = Name("UseAttachments")
+    "Attachments panel visible"
+
+
+class TextMarkupType(CoerciveEnum):
+    "Subtype of a text markup annotation"
+
+    HIGHLIGHT = Name("Highlight")
+
+    UNDERLINE = Name("Underline")
+
+    SQUIGGLY = Name("Squiggly")
+
+    STRIKE_OUT = Name("StrikeOut")
 
 
 class BlendMode(CoerciveEnum):
@@ -257,6 +354,49 @@ class BlendMode(CoerciveEnum):
     """
 
 
+class AnnotationFlag(CoerciveIntEnum):
+    INVISIBLE = 1
+    """
+    If set, do not display the annotation if it does not belong to one of the
+    standard annotation types and no annotation handler is available.
+    """
+    HIDDEN = 2
+    "If set, do not display or print the annotation or allow it to interact with the user"
+    PRINT = 4
+    "If set, print the annotation when the page is printed."
+    NO_ZOOM = 8
+    "If set, do not scale the annotation’s appearance to match the magnification of the page."
+    NO_ROTATE = 16
+    "If set, do not rotate the annotation’s appearance to match the rotation of the page."
+    NO_VIEW = 32
+    "If set, do not display the annotation on the screen or allow it to interact with the user"
+    READ_ONLY = 64
+    """
+    If set, do not allow the annotation to interact with the user.
+    The annotation may be displayed or printed but should not respond to mouse clicks.
+    """
+    LOCKED = 128
+    """
+    If set, do not allow the annotation to be deleted or its properties
+    (including position and size) to be modified by the user.
+    """
+    TOGGLE_NO_VIEW = 256
+    "If set, invert the interpretation of the NoView flag for certain events."
+    LOCKED_CONTENTS = 512
+    "If set, do not allow the contents of the annotation to be modified by the user."
+
+
+class AnnotationName(CoerciveEnum):
+    "The name of an icon that shall be used in displaying the annotation"
+
+    NOTE = Name("Note")
+    COMMENT = Name("Comment")
+    HELP = Name("Help")
+    PARAGRAPH = Name("Paragraph")
+    NEW_PARAGRAPH = Name("NewParagraph")
+    INSERT = Name("Insert")
+
+
 class IntersectionRule(CoerciveEnum):
     """
     An enumeration representing the two possible PDF intersection rules.
@@ -432,3 +572,14 @@ class PDFStyleKeys(Enum):
     STROKE_JOIN_STYLE = Name("LJ")
     STROKE_MITER_LIMIT = Name("ML")
     STROKE_DASH_PATTERN = Name("D")  # array of array, number, e.g. [[1 1] 0]
+
+
+class Corner(CoerciveEnum):
+    TOP_RIGHT = "TOP_RIGHT"
+    TOP_LEFT = "TOP_LEFT"
+    BOTTOM_RIGHT = "BOTTOM_RIGHT"
+    BOTTOM_LEFT = "BOTTOM_LEFT"
+
+
+# This enum is only used internally:
+__pdoc__ = {"DocumentState": False}
