@@ -1,8 +1,15 @@
 import math
 import re
+import warnings
 from typing import NamedTuple
 
-from defusedxml.ElementTree import fromstring as parse_xml_str
+try:
+    from defusedxml.ElementTree import fromstring as parse_xml_str
+except ImportError:
+    warnings.warn(
+        "defusedxml could not be imported - fpdf2 will not be able to sanitize SVG images provided"
+    )
+    from xml.etree.ElementTree import fromstring as parse_xml_str  # nosec
 
 from . import drawing, html
 
@@ -257,9 +264,29 @@ svg_attr_map = {
 }
 
 
+@force_nodocument
+def parse_style(svg_element):
+    """Parse `style="..."` making it's key-value pairs element's attributes"""
+    try:
+        style = svg_element.attrib["style"]
+    except KeyError:
+        pass
+    else:
+        for element in style.split(";"):
+            if not element:
+                continue
+
+            pair = element.split(":")
+            if len(pair) == 2 and pair[0] and pair[1]:
+                attr, value = pair
+
+                svg_element.attrib[attr.strip()] = value.strip()
+
+
 @force_nodocument
 def apply_styles(stylable, svg_element):
     """Apply the known styles from `svg_element` to the pdf path/group `stylable`."""
+    parse_style(svg_element)
 
     stylable.style.auto_close = False
 
@@ -993,8 +1020,8 @@ class SVGObject:
             if child.tag in xmlns_lookup("svg", "path"):
                 self.build_path(child)
 
-    # this assumes xrefs only reference already-defined ids. I don't know if this is
-    # required by the SVG spec.
+    # this assumes xrefs only reference already-defined ids.
+    # I don't know if this is required by the SVG spec.
     @force_nodocument
     def build_xref(self, xref):
         """Resolve a cross-reference to an already-seen SVG element by ID."""
@@ -1017,6 +1044,13 @@ class SVGObject:
                 f"use {xref} references nonexistent ref id {ref}"
             ) from None
 
+        if "x" in xref.attrib or "y" in xref.attrib:
+            # Quoting the SVG spec - 5.6.2. Layout of re-used graphics:
+            # > The x and y properties define an additional transformation translate(x,y)
+            x, y = float(xref.attrib.get("x", 0)), float(xref.attrib.get("y", 0))
+            pdf_group.transform = drawing.Transform.translation(x=x, y=y)
+        # Note that we currently do not support "width" & "height" in <use>
+
         return pdf_group
 
     @force_nodocument
