@@ -299,9 +299,7 @@ class TTFontFile:
             fsType = self.read_ushort()
             if fsType == 0x0002 or (fsType & 0x0300) != 0:
                 raise RuntimeError(
-                    "ERROR - Font file "
-                    + self.filename
-                    + " cannot be embedded due to copyright restrictions."
+                    f"ERROR - Font file {self.filename} cannot be embedded due to copyright restrictions."
                 )
 
             self.skip(20)
@@ -393,7 +391,11 @@ class TTFontFile:
                 if fmt == 4:
                     if not unicode_cmap_offset:
                         unicode_cmap_offset = cmap_offset + offset
-                    break
+                    # Don't break here since we might later get
+                    # unicode_cmap_offset12 which is needed for
+                    # characters => 0x10000 (CMAP12)
+                    #
+                    # break
 
             self.seek(save_pos)
 
@@ -470,7 +472,11 @@ class TTFontFile:
                     fmt = self.get_ushort(cmap_offset + offset)
                     if fmt == 4:
                         unicode_cmap_offset = cmap_offset + offset
-                        break
+                        # Don't break here since we might later get
+                        # unicode_cmap_offset12 which is needed for
+                        # characters => 0x10000 (CMAP12)
+                        #
+                        # break
 
                 self.seek(save_pos)
 
@@ -500,12 +506,17 @@ class TTFontFile:
             subsetglyphs = [(0, 0)]  # special "sorted dict"!
             subsetCharToGlyph = {}
             for code in subset:
+                target = subset[code] if isinstance(subset, dict) else code
+                if target > 65535:
+                    raise Exception(
+                        f"Character U+{target:X} must be remapped since it cannot be indexed in CMAP4 table"
+                    )
                 if code in self.charToGlyph:
-                    if (self.charToGlyph[code], code) not in subsetglyphs:
+                    if (self.charToGlyph[code], target) not in subsetglyphs:
                         subsetglyphs.append(
-                            (self.charToGlyph[code], code)
+                            (self.charToGlyph[code], target)
                         )  # Old Glyph ID => Unicode
-                    subsetCharToGlyph[code] = self.charToGlyph[
+                    subsetCharToGlyph[target] = self.charToGlyph[
                         code
                     ]  # Unicode to old GlyphID
                 self.maxUni = max(self.maxUni, code)
